@@ -22,8 +22,7 @@ import numba as nb
 class Tts(TwoToneSpectroscopy):
 
     def __init__(self,
-                 *, x_min, x_max, nx_points, y_min, y_max, ny_points,
-                 x_step, y_step,
+                 *, x_min, x_max, y_min, y_max,
                  fr_min: float, fr_max: float,
                  hdawg_port: str = '127.0.0.1', hdawg_port1: int = 8004, hdawg_port2: int = 6,
                  LO_port: str = 'TCPIP0::192.168.180.143::hislip0::INSTR',
@@ -31,7 +30,7 @@ class Tts(TwoToneSpectroscopy):
                  hdawg_channel: int = 5, hdawg_setDouble: str = '/dev8210/sigouts/5/offset',
                  LO_set_power: int = 5,
                  LO_res_set_bandwidth: int = 20, LO_res_set_power: int = -10, LO_res_set_nop=101,
-                 base_bandwidth=40
+                 base_bandwidth=40, nx_points = None, x_step=None, y_step=None, ny_points=None
                  ):
         """
         Class provides methods for working with live data for Two Tone Spectroscopy
@@ -64,7 +63,7 @@ class Tts(TwoToneSpectroscopy):
         self.hdawg = zhinst.ziPython.ziDAQServer(hdawg_port, hdawg_port1, hdawg_port2)
         self.hdawg_setDouble = hdawg_setDouble
         # open HDAWG ZI
-        hdawgModule = hdawg.awgModule()
+        hdawgModule = self.hdawg.awgModule()
         channel = hdawg_channel
         self.hdawg.setInt('/dev8210/sigouts/' + str(channel) + '/on', 1)
 
